'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _superagent = require('superagent');

var _superagent2 = _interopRequireDefault(_superagent);

var _ArgumentError = require('./errors/ArgumentError');

var _ArgumentError2 = _interopRequireDefault(_ArgumentError);

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var ArmClient = function () {
  function ArmClient(options) {
    _classCallCheck(this, ArmClient);

    options.managementEndpoint = options.managementEndpoint || _constants.MANAGEMENT_ENDPOINT;
    if (!options.managementEndpoint || options.managementEndpoint.length === 0) {
      throw new _ArgumentError2.default('The ARM client requires a managementEndpoint.');
    }

    if (!options.subscriptionId || options.subscriptionId.length === 0) {
      throw new _ArgumentError2.default('The ARM client requires a subscriptionId.');
    }

    this.options = options;
  }

  _createClass(ArmClient, [{
    key: 'buildRequest',
    value: function buildRequest(method, path, query, accessToken) {
      if (!path || path.indexOf('https://') < 0) {
        path = this.options.managementEndpoint + '/subscriptions/' + this.options.subscriptionId + path;
      }

      return (0, _superagent2.default)(method, path).query(query || {}).set('Authorization', 'Bearer ' + accessToken).set('Accept', 'application/json');
    }
  }, {
    key: 'handleResponse',
    value: function handleResponse(resolve, reject) {
      return function (err, res) {
        if (err && res && !res.ok) {
          return reject({
            status: res.status,
            details: res.body || res.text
          });
        } else if (err) {
          return reject(err);
        } else {
          return resolve({ body: res.body, headers: res.header });
        }
      };
    }
  }, {
    key: 'provider',
    value: function provider(resourceGroupName, providerName) {
      var _this = this;

      return {
        get: function get(path, query) {
          return _this.get('/resourceGroups/' + resourceGroupName + '/providers/' + providerName + path, query);
        },
        post: function post(path, query, payload) {
          return _this.post('/resourceGroups/' + resourceGroupName + '/providers/' + providerName + path, query, payload);
        },
        put: function put(path, query, payload) {
          return _this.put('/resourceGroups/' + resourceGroupName + '/providers/' + providerName + path, query, payload);
        },
        del: function del(path, query, payload) {
          return _this.del('/resourceGroups/' + resourceGroupName + '/providers/' + providerName + path, query, payload);
        }
      };
    }
  }, {
    key: 'get',
    value: function get(path, query) {
      var _this2 = this;

      return this.options.auth().then(function (accessToken) {
        return new Promise(function (resolve, reject) {
          _this2.buildRequest('GET', path, query, accessToken).end(_this2.handleResponse(resolve, reject));
        });
      });
    }
  }, {
    key: 'post',
    value: function post(path, query, payload) {
      var _this3 = this;

      return this.options.auth().then(function (accessToken) {
        return new Promise(function (resolve, reject) {
          _this3.buildRequest('POST', path, query, accessToken).send(payload || {}).end(_this3.handleResponse(resolve, reject));
        });
      });
    }
  }, {
    key: 'put',
    value: function put(path, query, payload) {
      var _this4 = this;

      return this.options.auth().then(function (accessToken) {
        return new Promise(function (resolve, reject) {
          _this4.buildRequest('PUT', path, query, accessToken).send(payload || {}).end(_this4.handleResponse(resolve, reject));
        });
      });
    }
  }, {
    key: 'del',
    value: function del(path, query, payload) {
      var _this5 = this;

      return this.options.auth().then(function (accessToken) {
        return new Promise(function (resolve, reject) {
          _this5.buildRequest('DELETE', path, query, accessToken).send(payload || {}).end(_this5.handleResponse(resolve, reject));
        });
      });
    }
  }]);

  return ArmClient;
}();

exports.default = ArmClient;