'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = clientCredentials;

var _jsonwebtoken = require('jsonwebtoken');

var _jsonwebtoken2 = _interopRequireDefault(_jsonwebtoken);

var _adalNode = require('adal-node');

var _adalNode2 = _interopRequireDefault(_adalNode);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _ArgumentError = require('../errors/ArgumentError');

var _ArgumentError2 = _interopRequireDefault(_ArgumentError);

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function clientCredentials(options) {
  if (!options || !(options instanceof Object)) {
    throw new _ArgumentError2.default('The Client Credentials options must be an object.');
  }

  options.managementEndpoint = options.managementEndpoint || _constants.MANAGEMENT_ENDPOINT;
  if (!options.managementEndpoint || options.managementEndpoint.length === 0) {
    throw new _ArgumentError2.default('Client Credentials authentication requires a managementEndpoint.');
  }

  options.authenticationEndpoint = options.authenticationEndpoint || _constants.AUTHENTICATION_ENDPOINT;
  if (!options.authenticationEndpoint || options.authenticationEndpoint.length === 0) {
    throw new _ArgumentError2.default('Client Credentials authentication requires an authenticationEndpoint.');
  }

  if (!options.tenantId || options.tenantId.length === 0) {
    throw new _ArgumentError2.default('Client Credentials authentication requires a tenantId.');
  }

  if (!options.clientId || options.clientId.length === 0) {
    throw new _ArgumentError2.default('Client Credentials authentication requires a clientId.');
  }

  if ((!options.clientSecret || options.clientSecret.length === 0) && (!options.servicePrincipalPassword || options.servicePrincipalPassword.length === 0)) {
    throw new _ArgumentError2.default('Client Credentials authentication requires a clientSecret or servicePrincipalPassword.');
  }

  var expiresIn = 60;
  var accessToken = null;
  var accessTokenIssued = null;

  return function () {
    return new _bluebird2.default(function (resolve, reject) {
      if (accessTokenIssued) {
        var timeAgo = (0, _moment2.default)(new Date()).diff(accessTokenIssued, 'minutes');
        if (timeAgo < expiresIn - 10) {
          return resolve(accessToken);
        }
      }

      var context = new _adalNode2.default.AuthenticationContext(options.authenticationEndpoint + '/' + options.tenantId);
      context.acquireTokenWithClientCredentials(options.managementEndpoint + '/', options.clientId, options.clientSecret || options.servicePrincipalPassword, function (err, res) {
        if (err) {
          return reject(err);
        }

        accessToken = res.accessToken;
        accessTokenIssued = new Date();

        // Calculate expiration.
        var accessTokenContents = _jsonwebtoken2.default.decode(res.accessToken);
        expiresIn = Math.round(_moment2.default.duration((0, _moment2.default)(new Date(accessTokenContents.exp * 1000)).diff((0, _moment2.default)(new Date(accessTokenContents.iat * 1000)))).asMinutes());

        return resolve(accessToken);
      });
    });
  };
}